@@ -29,7 +29,7 @@ class MainWindow : public KXmlGuiWindow
 {
     Q_OBJECT
 public:
-    explicit MainWindow(QWidget *parent = 0);
+    explicit MainWindow(QWidget *parent = nullptr);
     ~MainWindow() override;
 
 public Q_SLOTS:
